@@ -52,38 +52,43 @@ class PMA_Scripts
     {
         $first_dynamic_scripts = "";
         $dynamic_scripts = "";
-        $params = array();
+        $scripts = array();
         foreach ($files as $value) {
-            if (strpos($value['filename'], "?") === false) {
-                $include = true;
-                if ($value['conditional_ie'] !== false
-                    && PMA_USR_BROWSER_AGENT === 'IE'
-                ) {
-                    if ($value['conditional_ie'] === true) {
-                        $include = true;
-                    } else if ($value['conditional_ie'] == PMA_USR_BROWSER_VER) {
-                        $include = true;
-                    } else {
-                        $include = false;
-                    }
-                }
-                if ($include) {
-                    $scripts[] = "scripts[]=" . $value['filename'];
-                }
-            } else {
+            if (/*overload*/mb_strpos($value['filename'], "?") !== false) {
                 if ($value['before_statics'] === true) {
-                    $first_dynamic_scripts .= "<script type='text/javascript' src='js/"
+                    $first_dynamic_scripts
+                        .= "<script type='text/javascript' src='js/"
                         . $value['filename'] . "'></script>";
                 } else {
                     $dynamic_scripts .= "<script type='text/javascript' src='js/"
                         . $value['filename'] . "'></script>";
                 }
+                continue;
+            }
+            $include = true;
+            if ($value['conditional_ie'] !== false
+                && PMA_USR_BROWSER_AGENT === 'IE'
+            ) {
+                if ($value['conditional_ie'] === true) {
+                    $include = true;
+                } else if ($value['conditional_ie'] == PMA_USR_BROWSER_VER) {
+                    $include = true;
+                } else {
+                    $include = false;
+                }
+            }
+            if ($include) {
+                $scripts[] = "scripts[]=" . $value['filename'];
             }
         }
+        $separator = PMA_URL_getArgSeparator();
+        $url = 'js/get_scripts.js.php'
+            . PMA_URL_getCommon(array(), 'none')
+            . $separator . implode($separator, $scripts);
+
         $static_scripts = sprintf(
-            '<script type="text/javascript" '
-            . 'src="js/get_scripts.js.php%s&%s"></script>',
-            PMA_URL_getCommon(array(), 'none'), implode("&", $scripts)
+            '<script type="text/javascript" src="%s"></script>',
+            htmlspecialchars($url)
         );
         return $first_dynamic_scripts . $static_scripts . $dynamic_scripts;
     }
@@ -112,17 +117,38 @@ class PMA_Scripts
      *
      * @return void
      */
-    public function addFile($filename, $conditional_ie = false, $before_statics = false)
-    {
+    public function addFile(
+        $filename,
+        $conditional_ie = false,
+        $before_statics = false
+    ) {
         $hash = md5($filename);
-        if (empty($this->_files[$hash])) {
-            $has_onload = $this->_eventBlacklist($filename);
-            $this->_files[$hash] = array(
-                'has_onload' => $has_onload,
-                'filename' => $filename,
-                'conditional_ie' => $conditional_ie,
-                'before_statics' => $before_statics
-            );
+        if (!empty($this->_files[$hash])) {
+            return;
+        }
+
+        $has_onload = $this->_eventBlacklist($filename);
+        $this->_files[$hash] = array(
+            'has_onload' => $has_onload,
+            'filename' => $filename,
+            'conditional_ie' => $conditional_ie,
+            'before_statics' => $before_statics
+        );
+    }
+
+    /**
+     * Add new files to the list of scripts
+     *
+     * @param array $filelist       The array of file names
+     * @param bool  $conditional_ie Whether to wrap the script tag in
+     *                              conditional comments for IE
+     *
+     * @return void
+     */
+    public function addFiles($filelist, $conditional_ie = false)
+    {
+        foreach ($filelist as $filename) {
+            $this->addFile($filename, $conditional_ie);
         }
     }
 
@@ -145,9 +171,9 @@ class PMA_Scripts
             || strpos($filename, 'cross_framing_protection.js') !== false
         ) {
             return 0;
-        } else {
-            return 1;
         }
+
+        return 1;
     }
 
     /**
@@ -190,13 +216,16 @@ class PMA_Scripts
     {
         $retval = array();
         foreach ($this->_files as $file) {
-            if (strpos($file['filename'], "?") === false) {
-                if (! $file['conditional_ie'] || PMA_USR_BROWSER_AGENT == 'IE') {
-                    $retval[] = array(
-                        'name' => $file['filename'],
-                        'fire' => $file['has_onload']
-                    );
-                }
+            //If filename contains a "?", continue.
+            if (strpos($file['filename'], "?") !== false) {
+                continue;
+            }
+
+            if (! $file['conditional_ie'] || PMA_USR_BROWSER_AGENT == 'IE') {
+                $retval[] = array(
+                    'name' => $file['filename'],
+                    'fire' => $file['has_onload']
+                );
             }
         }
         return $retval;
