@@ -34,9 +34,11 @@ function PMA_getUrlParams(
         'query_type' => $what,
         'reload' => (! empty($reload) ? 1 : 0),
     );
-    if (strpos(' ' . $action, 'db_') == 1) {
+    if (/*overload*/mb_strpos(' ' . $action, 'db_') == 1) {
         $_url_params['db']= $db;
-    } elseif (strpos(' ' . $action, 'tbl_') == 1 || $what == 'row_delete') {
+    } elseif (/*overload*/mb_strpos(' ' . $action, 'tbl_') == 1
+        || $what == 'row_delete'
+    ) {
         $_url_params['db']= $db;
         $_url_params['table']= $table;
     }
@@ -71,7 +73,7 @@ function PMA_getUrlParams(
  * @param array  $selected    selected tables
  * @param string $db          db name
  * @param string $table       table name
- * @param string $views       table views
+ * @param array  $views       table views
  * @param string $primary     table primary
  * @param string $from_prefix from prefix original
  * @param string $to_prefix   to prefix original
@@ -224,8 +226,17 @@ function PMA_getQueryStrFromSelected(
 
         case 'replace_prefix_tbl':
             $current = $selected[$i];
-            if (substr($current, 0, strlen($from_prefix)) == $from_prefix) {
-                $newtablename = $to_prefix . substr($current, strlen($from_prefix));
+            $subFromPrefix = /*overload*/mb_substr(
+                $current,
+                0,
+                /*overload*/mb_strlen($from_prefix)
+            );
+            if ($subFromPrefix == $from_prefix) {
+                $newtablename = $to_prefix
+                    . /*overload*/mb_substr(
+                        $current,
+                        /*overload*/mb_strlen($from_prefix)
+                    );
             } else {
                 $newtablename = $current;
             }
@@ -239,12 +250,8 @@ function PMA_getQueryStrFromSelected(
 
         case 'copy_tbl_change_prefix':
             $current = $selected[$i];
-            if (substr($current, 0, strlen($from_prefix)) == $from_prefix) {
-                $newtablename = $to_prefix . substr($current, strlen($from_prefix));
-            } else {
-                $newtablename = $current;
-            }
-            $newtablename = $to_prefix . substr($current, strlen($from_prefix));
+            $newtablename = $to_prefix .
+                /*overload*/mb_substr($current, /*overload*/mb_strlen($from_prefix));
             // COPY TABLE AND CHANGE PREFIX PATTERN
             $a_query = 'CREATE TABLE '
                 . PMA_Util::backquote($newtablename)
@@ -276,7 +283,7 @@ function PMA_getQueryStrFromSelected(
 
     if ($deletes && ! empty($_REQUEST['pos'])) {
         $_REQUEST['pos'] = PMA_calculatePosForLastPage(
-            $db, $table, $_REQUEST['pos']
+            $db, $table, isset($_REQUEST['pos']) ? $_REQUEST['pos'] : null
         );
     }
 
@@ -464,12 +471,12 @@ function PMA_getHtmlForOtherActions($what, $action, $_url_params, $full_query)
  * Get List of information for Submit Mult
  *
  * @param string $submit_mult mult_submit type
- * @param string $db          dtabase name
- * @param array  $table       table name
+ * @param string $db          database name
+ * @param string $table       table name
  * @param array  $selected    the selected columns
- * @param array  $action      action type
+ * @param string $action      action type
  *
- * @return array()
+ * @return array
  */
 function PMA_getDataForSubmitMult($submit_mult, $db, $table, $selected, $action)
 {
@@ -477,7 +484,7 @@ function PMA_getDataForSubmitMult($submit_mult, $db, $table, $selected, $action)
     $query_type = null;
     $is_unset_submit_mult = false;
     $mult_btn = null;
-
+    $centralColsError = null;
     switch ($submit_mult) {
     case 'drop':
         $what     = 'drop_fld';
@@ -515,6 +522,14 @@ function PMA_getDataForSubmitMult($submit_mult, $db, $table, $selected, $action)
         $query_type = 'fulltext_fld';
         $mult_btn   = __('Yes');
         break;
+    case 'add_to_central_columns':
+        include_once 'libraries/central_columns.lib.php';
+        $centralColsError = PMA_syncUniqueColumns($selected, false);
+        break;
+    case 'remove_from_central_columns':
+        include_once 'libraries/central_columns.lib.php';
+        $centralColsError = PMA_deleteColumnsFromList($selected, false);
+        break;
     case 'change':
         PMA_displayHtmlForColumnChange($db, $table, $selected, $action);
         // execution stops here but PMA_Response correctly finishes
@@ -524,22 +539,24 @@ function PMA_getDataForSubmitMult($submit_mult, $db, $table, $selected, $action)
         // this should already be handled by tbl_structure.php
     }
 
-    return array($what, $query_type, $is_unset_submit_mult, $mult_btn);
+    return array(
+        $what, $query_type, $is_unset_submit_mult, $mult_btn,
+        $centralColsError
+            );
 }
 
 /**
  * Get query string from Selected
  *
  * @param string $what     mult_submit type
- * @param string $db       dtabase name
- * @param array  $table    table name
+ * @param string $db       database name
+ * @param string $table    table name
  * @param array  $selected the selected columns
- * @param array  $action   action type
  * @param array  $views    table views
  *
- * @return array()
+ * @return array
  */
-function PMA_getQueryFromSelected($what, $db, $table, $selected, $action, $views)
+function PMA_getQueryFromSelected($what, $db, $table, $selected, $views)
 {
     $reload = null;
     $full_query_views = null;
@@ -554,13 +571,14 @@ function PMA_getQueryFromSelected($what, $db, $table, $selected, $action, $views
     foreach ($selected as $sval) {
         switch ($what) {
         case 'row_delete':
-            $full_query .= 'DELETE FROM ' . PMA_Util::backquote($db)
-                . '.' . PMA_Util::backquote($table)
+            $full_query .= 'DELETE FROM '
+                . PMA_Util::backquote(htmlspecialchars($db))
+                . '.' . PMA_Util::backquote(htmlspecialchars($table))
                 // Do not append a "LIMIT 1" clause here
                 // (it's not binlog friendly).
                 // We don't need the clause because the calling panel permits
                 // this feature only when there is a unique index.
-                . ' WHERE ' . urldecode($sval)
+                . ' WHERE ' . urldecode(htmlspecialchars($sval))
                 . ';<br />';
             break;
         case 'drop_db':
